@@ -17,7 +17,7 @@ graphical video and audio batch converter
 all
 </installable>
 
-<screenshot>none</screenshot>
+<screenshot>https://screenshots.debian.net/screenshots/000/009/557/large.png</screenshot>
 
 <preinstall>
 
